# Bots

Boilerplate code for making web scrapers and bots powered by Selenium.

Start up a browser driven by selenium by running `python bot.py`

For this to work, you will need to have
1. Downloaded and unzipped [Chromedriver](https://chromedriver.chromium.org/downloads)
2. Added it to your path by moving it to `/usr/local/bin` (Mac/Linux) or somewhere else (Windows... look it up)
